::: upbankapi.models.Transaction

::: upbankapi.models.transactions.AsyncTransaction

::: upbankapi.models.common.MoneyObject

::: upbankapi.models.transactions.HoldInfo

::: upbankapi.models.transactions.RoundUp

::: upbankapi.models.transactions.Cashback
